<?php

namespace App\Commands;

use Illuminate\Console\Scheduling\Schedule;
use LaravelZero\Framework\Commands\Command;

/**
 *  Remove LetsEncrypt Cerficates
 *
 *  @author Björn Hase, Tentakelfabrik
 *  @license http://opensource.org/licenses/MIT The MIT License
 *  @link https://gitea.tentakelfabrik.de/Tentakelfabrik/mcp
 *
 */
class LetsEncryptRemoveCommand extends Command
{
    // directory
    const CERT_DIR = '/etc/letsencrypt/';

    /**
     * The signature of the command.
     *
     * @var string
     */
    protected $signature = 'lets-encrypt:remove {domain*}';

    /**
     * The description of the command.
     *
     * @var string
     */
    protected $description = 'Remove Certificates from LetsEncrypt';

    /**
     * Execute the console command.
     *
     * @return mixed
     *
     */
    public function handle()
    {
        $domains = $this->argument('domain');

        foreach($domains as $domain) {

            $directories = [
                'archive' => self::CERT_DIR.'archive/'.$domain,
                'live' => self::CERT_DIR.'live/'.$domain,
                'renewal' => self::CERT_DIR.'renewal/'.$domain
            ];

            $errors = 0;

            // check for files and directories to delete
            foreach($directories as $key => $directory) {

                if ($key === 'renewal') {
                    $directory .= '.conf';
                }

                if (!file_exists($directory)) {
                    $errors++;
                } else {
                    if (is_file($directory)) {
                        system('rm '.$directory.' 2>&1');
                    } else {
                        system('rm -rf '.$directory.' 2>&1');
                    }
                }
            }

            if ($errors === count($directories)) {
                $this->error('Error! Certificate for '.$domain.'...not found!');
            }

            if ($errors > 0 && $errors < count($directories)) {
                $this->error('Trouble! Certificate for '.$domain.'...delete! Some files were not found!');
            }

            if ($errors === 0) {
                $this->info('Success! Certificate for '.$domain.'...deleted!');
            }
        }
    }
}
